"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeProgram = makeProgram;
exports.testCli = testCli;

var _commander = require("commander");

var _torchlight = _interopRequireDefault(require("./torchlight"));

var _highlight = _interopRequireDefault(require("./commands/highlight"));

var _init = _interopRequireDefault(require("./commands/init"));

var _clear = _interopRequireDefault(require("./commands/cache/clear"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Configure the commander CLI application.
 *
 * @param options
 * @return {Command}
 */
function makeProgram(options = {}) {
  if (options !== null && options !== void 0 && options.testing) {
    // Don't exit when there are errors, so we
    // can catch them.
    _commander.program.exitOverride(); // Capture the output, so we can inspect it.


    _commander.program.configureOutput({
      writeOut: () => {//
      },
      writeErr: () => {//
      },
      ...((options === null || options === void 0 ? void 0 : options.configureOutput) || {})
    });
  } // Bootstrap the Torchlight singleton before every command.


  _commander.program.hook('preAction', thisCommand => {
    _torchlight.default.init(thisCommand.opts().config);
  });

  makeCommand('_default_', _highlight.default).description('Highlight code blocks in source files').option('-i, --input <directory>', 'Input directory. Defaults to current directory.').option('-o, --output <directory>', 'Output directory. Defaults to current directory.').option('-n, --include <patterns>', 'Glob patterns used to search for source files. Separate ' + 'multiple patterns with commas. Defaults to "**/*.htm,**/*.html".').option('-x, --exclude <patterns>', 'String patterns to ignore (not globs). Separate multiple ' + 'patterns with commas. Defaults to "/node_modules/,/vendor/".').option('-w, --watch', 'Watch source files for changes.');
  makeCommand('init', _init.default).description('Publish the Torchlight configuration file.').option('-p, --path <path>', 'Location for the configuration file.');
  makeCommand('cache:clear', _clear.default).description('Clear the cache');
  return _commander.program;
}
/**
 * Run the CLI for testing purposes
 *
 * @param args
 * @param opts
 */


function testCli(args, opts) {
  // https://github.com/shadowspawn/forest-arborist/blob/master/src/command.ts#L345
  return makeProgram({ ...opts,
    testing: true
  }).parse(args, {
    from: 'user'
  });
}
/**
 * @param name
 * @return {Command}
 */


function makeCommand(name, handler) {
  let cmd = _commander.program;

  if (name !== '_default_') {
    // Name the other commands.
    cmd = cmd.command(name);
  } // Add a little shim around the handler so we can pass the
  // torchlight variable in, just for convenience.


  cmd.action(function (options) {
    return handler(_torchlight.default, options);
  }); // Every command gets the -c option, so the developer can
  // specify a path to a config file.

  return cmd.option('-c, --config <file>', 'Path to the Torchlight configuration file.');
}